'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _json = require('json5');

var _json2 = _interopRequireDefault(_json);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _lodash = require('lodash');

var _utils = require('./utils');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * LOOKUP BABEL CONFIGURATION
 * ==========================
 */


var debug = (0, _debug2.default)('eslint:plugin:import-resolver-babel-namespace:map-babel-namespace');

/**
 * Find the source maps of the babel namespaces.
 * The lookup babel configuration logic is starting from the directory of the file being transpiled.
 *
 * @see http://babeljs.io/docs/usage/babelrc/#lookup-behavior
 *
 * @param {String} directory
 * @return {Object|null}
 */
var lookupBabelConfiguration = function lookupBabelConfiguration(directory) {
    if (!directory) {
        return null;
    }

    debug('Resolving a babel configuration');

    var babelrc = (0, _utils.lookup)(directory, '.babelrc');

    if (!babelrc || !babelrc.content) {
        debug('Babel configuration is not found');

        return null;
    }

    var babelrcJson = _json2.default.parse(babelrc.content);

    if (babelrcJson && (0, _lodash.isArray)(babelrcJson.plugins)) {
        var pluginConfig = babelrcJson.plugins.find(function (plugin) {
            return plugin[0] === 'namespace';
        });

        if (pluginConfig) {
            debug('Babel plugin module namespace is enabled using configuration: ', pluginConfig[1]);

            return pluginConfig[1];
        }
    }

    debug('Babel plugin module namespace is not enabled');

    return null;
};

exports.default = lookupBabelConfiguration;