'use strict';

Object.defineProperty(exports, "__esModule", {
    value: true
});

var _path = require('path');

var _path2 = _interopRequireDefault(_path);

var _pathIsInside = require('path-is-inside');

var _pathIsInside2 = _interopRequireDefault(_pathIsInside);

var _debug = require('debug');

var _debug2 = _interopRequireDefault(_debug);

var _eslintImportResolverNode = require('eslint-import-resolver-node');

var _eslintImportResolverNode2 = _interopRequireDefault(_eslintImportResolverNode);

var _babelPluginNamespace = require('babel-plugin-namespace');

var _lookupBabelConfiguration = require('./lookup-babel-configuration');

var _lookupBabelConfiguration2 = _interopRequireDefault(_lookupBabelConfiguration);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/**
 * RESOLVER
 * ========
 */


var debug = (0, _debug2.default)('eslint:plugin:import-resolver-babel-namespace:resolver');

/**
 * Find the full path to 'source', given 'file' as a full reference path.
 *
 * @param {String} modulePath The module to resolve
 * @param {String} sourceFile The source file's full path
 * @param {Object} config The configuration of this plugin
 *
 * @return {Object}
 */
var resolve = function resolve(modulePath, sourceFile) {
    var config = arguments.length <= 2 || arguments[2] === undefined ? {} : arguments[2];
    // eslint-disable-line no-unused-vars
    // @see lookupBabelConfiguration()
    var resolvePath = (0, _pathIsInside2.default)(sourceFile, process.cwd()) ? sourceFile : process.cwd();
    var configurations = (0, _lookupBabelConfiguration2.default)(resolvePath);

    debug('Start to resolve the module namespace: %s (%s)', modulePath, sourceFile);

    // should skip if the path is relative or absolute
    if (!configurations || modulePath && (_path2.default.isAbsolute(modulePath) || /^(\.)/.test(modulePath))) {
        // Another resolver will take care about it
        return {
            found: false
        };
    }

    var sourceMaps = (0, _babelPluginNamespace.generateSourceMaps)(configurations);

    if (sourceMaps) {
        debug('Babel plugin module namespace is using source maps: ', sourceMaps);
    }

    try {
        var modulePathTransform = (0, _babelPluginNamespace.transformModuleNamespace)(modulePath, sourceFile, sourceMaps) || modulePath;

        if (modulePathTransform) {
            debug('Modul path is successfully resolved: %s', modulePathTransform);

            return _eslintImportResolverNode2.default.resolve(modulePathTransform, sourceFile);
        }
    } catch (e) {
        debug('An exception has been thrown: %s', e.message);
    }

    // How actually we can reach this state? Is it contains bad configuration?
    return {
        found: false
    };
};

exports.default = resolve;